summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--nuttx/graphics/nxtk/nxtk_subwindowclip.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/nuttx/graphics/nxtk/nxtk_subwindowclip.c b/nuttx/graphics/nxtk/nxtk_subwindowclip.c
index 594e7d844..73dc1828b 100644
--- a/nuttx/graphics/nxtk/nxtk_subwindowclip.c
+++ b/nuttx/graphics/nxtk/nxtk_subwindowclip.c
@@ -102,9 +102,9 @@ void nxtk_subwindowclip(FAR struct nxtk_framedwindow_s *fwnd,
/* Temporarily, position the src rectangle in absolute screen coordinates */
- nxgl_rectoffset(&tmp, dest, bounds->pt1.x, bounds->pt1.y);
+ nxgl_rectoffset(&tmp, src, bounds->pt1.x, bounds->pt1.y);
- /* Clip the dest rectangle to lie within the client window region */
+ /* Clip the src rectangle to lie within the client window region */
nxgl_rectintersect(&tmp, &tmp, bounds);